@@ -122,10 +122,11 @@ def _deploy(test):
 
     _validate_base_directory()
     # Check and make output dir
-    # outdir = cwd + "/.idk.out"
-    # if not os.path.exists(outdir):
-    #     os.mkdir(outdir)
+    outdir = Path.cwd() + "/.idk.out"
+    if not os.path.exists(outdir):
+        os.mkdir(outdir)
 
+    _get_create_hashname()
     # hashname = _get_create_hashname()
 
     # compressd_dir = _gzip_dir(cwd)
